@@ -1,15 +1,15 @@
-# Copyright 2020 John Reese
+# Copyright 2022 Amethyst Reese
 # Licensed under the MIT license
 
 import logging
 import sys
 from pathlib import Path
-from typing import Optional
+from typing import Any, Callable, Optional
 
 import click
 import tomlkit
 
-from attribution import __author__, __version__
+from attribution import __version__
 from .generate import Changelog, VersionFile
 from .helpers import sh
 from .project import Project
@@ -48,19 +48,19 @@ def init() -> None:
         pyproject = tomlkit.document()
         add_newline = False
 
-    if "tool" not in pyproject:
+    tool = pyproject.get("tool", None)
+    if tool is None:
         if add_newline:
             pyproject.append(None, tomlkit.nl())
-        table = tomlkit.table()
+        tool = tomlkit.table()
         # gross, but prevents a blank [tool] table
-        table._is_super_table = True  # pylint: disable=protected-access
-        pyproject.append("tool", table)
+        tool._is_super_table = True
+        pyproject.append("tool", tool)
 
-    if "attribution" in pyproject["tool"]:
-        table = pyproject["tool"]["attribution"]
-    else:
+    table = tool.get("attribution", None)
+    if table is None:
         table = tomlkit.table()
-        pyproject["tool"].append("attribution", table)
+        tool.append("attribution", table)
 
     table["name"] = name
     table["package"] = package
@@ -75,6 +75,38 @@ def init() -> None:
         VersionFile(project).write()
 
 
+@main.command("debug")
+def debug() -> None:
+    """Dump debug info about project"""
+    pprint: Callable[[Any], None]
+    try:
+        import rich
+
+        pprint = rich.print
+    except ImportError:
+        pprint = click.echo
+
+    project = Project.load()
+    pprint(f"pyproject.toml: {project.pyproject_path()}")
+    pprint(project)
+
+
+@main.command("log")
+def show_log() -> None:
+    """Show log of revisions since last tag"""
+    project = Project.load()
+    if project.tags:
+        tag = project.tags[0]
+        log_cmd = ["git", "log", "--reverse", f"{tag.name}.."]
+    else:
+        log_cmd = ["git", "log", "--reverse"]
+
+    log_cmd += ["--invert-grep"]
+    for author in project.config["ignored_authors"]:
+        log_cmd += [f"--author={author}"]
+    sh(*log_cmd, raw=True)
+
+
 @main.command("generate")
 def generate() -> None:
     """Regenerate changelog from existing tags"""
@@ -110,7 +142,10 @@ def tag_release(version: Version, message: Optional[str]) -> None:
 
         if project.tags:
             tag = project.tags[0]
-            git_log = sh(f"git log --reverse {tag.name}..")
+            log_cmd = ["git", "log", "--reverse", f"{tag.name}..", "--invert-grep"]
+            for author in project.config["ignored_authors"]:
+                log_cmd += [f"--author={author}"]
+            git_log = sh(*log_cmd)
             tpl += f"#\n# Changes since {tag.name}:\n#\n"
             tpl += "".join(f"# {line}\n" for line in git_log.splitlines(keepends=False))
 
@@ -158,4 +193,4 @@ def tag_release(version: Version, message: Optional[str]) -> None:
 
 
 if __name__ == "__main__":
-    main(prog_name="attribution")  # pylint: disable=unexpected-keyword-arg
+    main(prog_name="attribution")
