@@ -1,4 +1,4 @@
-# Copyright 2020 John Reese
+# Copyright 2022 Amethyst Reese
 # Licensed under the MIT license
 
 import logging
@@ -9,7 +9,7 @@ from typing import Any, Dict, Optional
 import tomlkit
 from attr import dataclass
 
-from .helpers import sh, canonical_namespace
+from .helpers import canonical_namespace, sh
 from .tag import Tag, Tags
 
 LOG = logging.getLogger(__name__)
@@ -70,16 +70,35 @@ class Project:
         name = ""
         package = ""
         config: Dict[str, Any] = {
+            "ignored_authors": [],
             "version_file": True,
             "signed_tags": True,
         }
 
         if cls.pyproject_path(path).is_file():
             pyproject = tomlkit.loads(cls.pyproject_path(path).read_text())
-            if "tool" in pyproject and "attribution" in pyproject["tool"]:
-                config.update(pyproject["tool"]["attribution"])
+            tool = pyproject.get("tool", {})
+            tool_attribution = tool.get("attribution", {})
+            if tool_attribution:
+                config.update(tool_attribution)
                 name = config.get("name", "")
                 package = config.get("package", "")
+                ignored_authors = config.get("ignored_authors", [])
+
+                if ignored_authors:
+                    if isinstance(ignored_authors, str):
+                        config["ignored_authors"] = list(ignored_authors)
+                    elif isinstance(ignored_authors, list):
+                        for author in list(ignored_authors):
+                            if not isinstance(author, str):
+                                LOG.warning(
+                                    f"ignored_authors value {author!r} must be string"
+                                )
+                                ignored_authors.remove(author)
+                    else:
+                        LOG.warning("ignored_authors must be string or list of strings")
+                        ignored_authors = []
+                    config["ignored_authors"] = ignored_authors
 
         if not name:
             name = path.name
